import {
  AfterViewInit,
  Component,
  ElementRef,
  EventEmitter,
  OnInit,
  Output,
  ViewChild,
} from "@angular/core";
import WebViewer, { Core, WebViewerInstance } from "@pdftron/webviewer";
import { Subject } from "rxjs";

@Component({
  selector: "app-root",
  styleUrls: ["app.component.css"],
  templateUrl: "app.component.html",
})
export class AppComponent implements AfterViewInit {
  wvInstance?: WebViewerInstance;

  @ViewChild("viewer") viewer!: ElementRef;

  @Output() coreControlsEvent: EventEmitter<string> = new EventEmitter();

  private documentLoaded$: Subject<void>;

  private sequenceNumber: number = 101;

  constructor() {
    this.documentLoaded$ = new Subject<void>();
  }

  ngAfterViewInit(): void {
    WebViewer(
      {
        path: "../lib",
        fullAPI: true,
        initialDoc: "../files/science_journal_sample.pdf",
        enableAnnotationNumbering: true,
        //licenseKey: 'your_license_key'  // sign up to get a free trial key at https://dev.apryse.com
      },
      this.viewer.nativeElement
    ).then((instance) => {
      this.wvInstance = instance;

      this.coreControlsEvent.emit(instance.UI.LayoutMode.Single);

      const { documentViewer, Annotations, annotationManager } = instance.Core;

      instance.UI.openElements(["notesPanel"]);

      documentViewer.addEventListener("annotationsLoaded", () => {
        console.log("annotations loaded");
      });

      const { UI, Core } = instance;
      const { Color } = Annotations;

      annotationManager.addEventListener(
        "annotationChanged",
        (
          annotations: any,
          action: string,
          annotationChangedInfoObject: Core.AnnotationManager.AnnotationChangedInfoObject
        ) => {
          if (annotationChangedInfoObject.imported === true) {
            return;
          }

          annotations.forEach(
            async (annotation: Core.Annotations.Annotation) => {
              const xfdfData =
                await annotationManager.exportAnnotationCommand();
              console.warn("ID: " + annotation.Id);
              console.warn("save XFDF to datastore");
              console.warn(xfdfData);

              // Pretend we have do a POST http request that gives us back a number
              if (action === "add") {
                setTimeout(() => {
                  const nextNumber = this.sequenceNumber;
                  console.warn("nextNumber: " + nextNumber);
                  annotation.setAssociatedNumber(nextNumber);

                  this.sequenceNumber++;
                }, 2000);
              }
            }
          );
        }
      );
    });
  }
}
